@@ -122,7 +122,7 @@ fn main() {
         TreeSitterParser {
             name: "tree-sitter-haskell",
             src_dir: "vendor/tree-sitter-haskell-src",
-            extra_files: vec!["scanner.cc"],
+            extra_files: vec!["scanner.c"],
         },
         TreeSitterParser {
             name: "tree-sitter-janet-simple",
@@ -144,6 +144,11 @@ fn main() {
             src_dir: "vendor/tree-sitter-json-src",
             extra_files: vec![],
         },
+        TreeSitterParser {
+            name: "tree-sitter-kotlin",
+            src_dir: "vendor/tree-sitter-kotlin-src",
+            extra_files: vec!["scanner.c"],
+        },
         TreeSitterParser {
             name: "tree-sitter-lua",
             src_dir: "vendor/tree-sitter-lua-src",
@@ -189,6 +194,11 @@ fn main() {
             src_dir: "vendor/tree-sitter-scala-src",
             extra_files: vec!["scanner.c"],
         },
+        TreeSitterParser {
+            name: "tree-sitter-toml",
+            src_dir: "vendor/tree-sitter-toml-src",
+            extra_files: vec!["scanner.c"],
+        },
         TreeSitterParser {
             name: "tree-sitter-tsx",
             src_dir: "vendor/tree-sitter-typescript-src/tsx/src",
