@@ -8,6 +8,7 @@ const MAX_DISTANCE: usize = 4;
 use std::collections::{HashMap, HashSet};
 
 use crate::{
+    constants::Side,
     context::{add_context, opposite_positions, MAX_PADDING},
     lines::LineNumber,
     side_by_side::lines_with_novel,
@@ -344,12 +345,6 @@ fn lines_to_hunks(
     hunks
 }
 
-#[derive(Debug, Copy, Clone, PartialEq, Eq)]
-enum Side {
-    LHS,
-    RHS,
-}
-
 /// Given a sequence of novel MatchedPos values in a section between
 /// two unchanged MatchedPos values, return them in an order suited
 /// for displaying.
@@ -386,7 +381,7 @@ fn novel_section_in_order(
             false
         };
         if same_line_as_prev {
-            res.push((Side::LHS, (**lhs_mp).clone()));
+            res.push((Side::Left, (**lhs_mp).clone()));
             lhs_iter.next();
         } else {
             break;
@@ -399,7 +394,7 @@ fn novel_section_in_order(
             false
         };
         if same_line_as_prev {
-            res.push((Side::RHS, (**rhs_mp).clone()));
+            res.push((Side::Right, (**rhs_mp).clone()));
             rhs_iter.next();
         } else {
             break;
@@ -410,7 +405,7 @@ fn novel_section_in_order(
     // without any unchanged MatchedPos values.
     while let Some(lhs_mp) = lhs_iter.peek() {
         if !opposite_to_lhs.contains_key(&lhs_mp.pos.line) {
-            res.push((Side::LHS, (**lhs_mp).clone()));
+            res.push((Side::Left, (**lhs_mp).clone()));
             lhs_iter.next();
         } else {
             break;
@@ -418,7 +413,7 @@ fn novel_section_in_order(
     }
     while let Some(rhs_mp) = rhs_iter.peek() {
         if !opposite_to_rhs.contains_key(&rhs_mp.pos.line) {
-            res.push((Side::RHS, (**rhs_mp).clone()));
+            res.push((Side::Right, (**rhs_mp).clone()));
             rhs_iter.next();
         } else {
             break;
@@ -428,10 +423,10 @@ fn novel_section_in_order(
     // Finally, the remainder of the novel MatchedPos values will be
     // on the same line as the following unchanged MatchedPos value.
     for lhs_mp in lhs_iter {
-        res.push((Side::LHS, (*lhs_mp).clone()));
+        res.push((Side::Left, (*lhs_mp).clone()));
     }
     for rhs_mp in rhs_iter {
-        res.push((Side::RHS, (*rhs_mp).clone()));
+        res.push((Side::Right, (*rhs_mp).clone()));
     }
 
     res
@@ -459,8 +454,8 @@ fn sorted_novel_positions(
 
     let mut lhs_prev_matched_line = None;
     let mut rhs_prev_matched_line = None;
-    let mut lhs_section = vec![];
-    let mut rhs_section = vec![];
+    let mut lhs_novel_section = vec![];
+    let mut rhs_novel_section = vec![];
 
     let mut lhs_iter = lhs_mps.iter().peekable();
     let mut rhs_iter = rhs_mps.iter().peekable();
@@ -468,15 +463,15 @@ fn sorted_novel_positions(
         match (lhs_iter.peek(), rhs_iter.peek()) {
             (Some(lhs_mp), Some(rhs_mp)) if !lhs_mp.kind.is_novel() && !rhs_mp.kind.is_novel() => {
                 res.append(&mut novel_section_in_order(
-                    &lhs_section,
-                    &rhs_section,
+                    &lhs_novel_section,
+                    &rhs_novel_section,
                     lhs_prev_matched_line,
                     rhs_prev_matched_line,
                     opposite_to_lhs,
                     opposite_to_rhs,
                 ));
-                lhs_section = vec![];
-                rhs_section = vec![];
+                lhs_novel_section = vec![];
+                rhs_novel_section = vec![];
 
                 lhs_prev_matched_line = Some(lhs_mp.pos.line);
                 rhs_prev_matched_line = Some(rhs_mp.pos.line);
@@ -484,25 +479,25 @@ fn sorted_novel_positions(
                 rhs_iter.next();
             }
             (Some(lhs_mp), _) if lhs_mp.kind.is_novel() => {
-                lhs_section.push(lhs_mp);
+                lhs_novel_section.push(lhs_mp);
                 lhs_iter.next();
             }
             (_, Some(rhs_mp)) if rhs_mp.kind.is_novel() => {
-                rhs_section.push(rhs_mp);
+                rhs_novel_section.push(rhs_mp);
                 rhs_iter.next();
             }
             (None, None) => {
                 break;
             }
-            _ => {
-                unreachable!("Should be impossible: every LHS Unchanged MatchedPos should have a corresponding RHS Unchanged MatchedPos");
+            (lhs_mp, rhs_mp) => {
+                unreachable!("Should be impossible: every LHS Unchanged MatchedPos should have a corresponding RHS Unchanged MatchedPos\n  {:?}\n  {:?}", lhs_mp, rhs_mp);
             }
         }
     }
 
     res.append(&mut novel_section_in_order(
-        &lhs_section,
-        &rhs_section,
+        &lhs_novel_section,
+        &rhs_novel_section,
         lhs_prev_matched_line,
         rhs_prev_matched_line,
         opposite_to_lhs,
@@ -546,7 +541,7 @@ fn matched_novel_lines(
         let self_line = mp.pos.line;
 
         match side {
-            Side::LHS => {
+            Side::Left => {
                 let should_append = if let Some(highest_lhs) = highest_lhs {
                     self_line > highest_lhs
                 } else {
@@ -560,7 +555,7 @@ fn matched_novel_lines(
                     highest_lhs = Some(self_line);
                 }
             }
-            Side::RHS => {
+            Side::Right => {
                 let should_append = if let Some(highest_rhs) = highest_rhs {
                     self_line > highest_rhs
                 } else {
@@ -703,7 +698,7 @@ mod tests {
         let lhs_mps = vec![novel_mp.clone(), matched_mp.clone()];
         let res = sorted_novel_positions(&lhs_mps, &[matched_mp], &HashMap::new(), &HashMap::new());
 
-        assert_eq!(res, vec![(Side::LHS, novel_mp)]);
+        assert_eq!(res, vec![(Side::Left, novel_mp)]);
     }
 
     #[test]
