@@ -61,6 +61,7 @@ extern "C" {
     fn tree_sitter_java() -> ts::Language;
     fn tree_sitter_javascript() -> ts::Language;
     fn tree_sitter_json() -> ts::Language;
+    fn tree_sitter_kotlin() -> ts::Language;
     fn tree_sitter_lua() -> ts::Language;
     fn tree_sitter_nix() -> ts::Language;
     fn tree_sitter_ocaml() -> ts::Language;
@@ -70,6 +71,7 @@ extern "C" {
     fn tree_sitter_ruby() -> ts::Language;
     fn tree_sitter_rust() -> ts::Language;
     fn tree_sitter_scala() -> ts::Language;
+    fn tree_sitter_toml() -> ts::Language;
     fn tree_sitter_tsx() -> ts::Language;
     fn tree_sitter_typescript() -> ts::Language;
     fn tree_sitter_yaml() -> ts::Language;
@@ -304,7 +306,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 .unwrap(),
             }
         }
-        JanetSimple => {
+        Janet => {
             let language = unsafe { tree_sitter_janet_simple() };
             TreeSitterConfig {
                 name: "Janet",
@@ -379,6 +381,24 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 .unwrap(),
             }
         }
+        Kotlin => {
+            let language = unsafe { tree_sitter_kotlin() };
+            TreeSitterConfig {
+                name: "Kotlin",
+                language,
+                atom_nodes: vec!["line_string_literal", "character_literal"]
+                    .into_iter()
+                    .collect(),
+                delimiter_tokens: vec![("(", ")"), ("{", "}"), ("[", "]"), ("<", ">")]
+                    .into_iter()
+                    .collect(),
+                highlight_query: ts::Query::new(
+                    language,
+                    include_str!("../vendor/highlights/kotlin.scm"),
+                )
+                .unwrap(),
+            }
+        }
         Lua => {
             let language = unsafe { tree_sitter_lua() };
             TreeSitterConfig {
@@ -519,21 +539,16 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 .unwrap(),
             }
         }
-        TypeScript => {
-            let language = unsafe { tree_sitter_typescript() };
+        Toml => {
+            let language = unsafe { tree_sitter_toml() };
             TreeSitterConfig {
-                name: "TypeScript",
+                name: "TOML",
                 language,
-                atom_nodes: vec!["string", "template_string", "regex"]
-                    .into_iter()
-                    .collect(),
-                delimiter_tokens: vec![("{", "}"), ("(", ")"), ("[", "]"), ("<", ">")],
+                atom_nodes: vec!["string"].into_iter().collect(),
+                delimiter_tokens: vec![("{", "}"), ("[", "]")],
                 highlight_query: ts::Query::new(
                     language,
-                    concat!(
-                        include_str!("../vendor/highlights/javascript.scm"),
-                        include_str!("../vendor/highlights/typescript.scm"),
-                    ),
+                    include_str!("../vendor/highlights/toml.scm"),
                 )
                 .unwrap(),
             }
@@ -555,16 +570,36 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 .unwrap(),
             }
         }
+        TypeScript => {
+            let language = unsafe { tree_sitter_typescript() };
+            TreeSitterConfig {
+                name: "TypeScript",
+                language,
+                atom_nodes: vec!["string", "template_string", "regex"]
+                    .into_iter()
+                    .collect(),
+                delimiter_tokens: vec![("{", "}"), ("(", ")"), ("[", "]"), ("<", ">")],
+                highlight_query: ts::Query::new(
+                    language,
+                    concat!(
+                        include_str!("../vendor/highlights/javascript.scm"),
+                        include_str!("../vendor/highlights/typescript.scm"),
+                    ),
+                )
+                .unwrap(),
+            }
+        }
         Yaml => {
             let language = unsafe { tree_sitter_yaml() };
             TreeSitterConfig {
                 name: "YAML",
                 language,
-                atom_nodes: (vec![
+                atom_nodes: vec![
                     "string_scalar",
                     "double_quote_scalar",
                     "single_quote_scalar",
-                ])
+                    "block_scalar",
+                ]
                 .into_iter()
                 .collect(),
                 delimiter_tokens: (vec![("{", "}"), ("(", ")"), ("[", "]")]),
@@ -613,51 +648,51 @@ fn tree_highlights(
     src: &str,
     config: &TreeSitterConfig,
 ) -> HighlightedNodeIds {
-    let mut keyword_ish_capture_ids = vec![];
-    if let Some(idx) = config.highlight_query.capture_index_for_name("keyword") {
-        keyword_ish_capture_ids.push(idx);
-    }
-    if let Some(idx) = config.highlight_query.capture_index_for_name("operator") {
-        keyword_ish_capture_ids.push(idx);
-    }
-    if let Some(idx) = config.highlight_query.capture_index_for_name("constant") {
-        keyword_ish_capture_ids.push(idx);
-    }
-    if let Some(idx) = config.highlight_query.capture_index_for_name("boolean") {
-        keyword_ish_capture_ids.push(idx);
-    }
-    if let Some(idx) = config
-        .highlight_query
-        .capture_index_for_name("constant.builtin")
-    {
-        keyword_ish_capture_ids.push(idx);
-    }
-
+    let mut keyword_ish_capture_ids: Vec<u32> = vec![];
     let mut string_capture_ids = vec![];
-    if let Some(idx) = config.highlight_query.capture_index_for_name("string") {
-        string_capture_ids.push(idx);
-    }
-    if let Some(idx) = config.highlight_query.capture_index_for_name("character") {
-        string_capture_ids.push(idx);
-    }
-
     let mut type_capture_ids = vec![];
-    if let Some(idx) = config.highlight_query.capture_index_for_name("type") {
-        type_capture_ids.push(idx);
-    }
-    if let Some(idx) = config
-        .highlight_query
-        .capture_index_for_name("type.builtin")
-    {
-        type_capture_ids.push(idx);
-    }
-    if let Some(idx) = config.highlight_query.capture_index_for_name("label") {
+
+    // Query names are often written with namespacing, so
+    // highlights.scm might contain @constant or the more specific
+    // @constant.builtin.
+    //
+    // We support e.g. arbitrary @constant.foo so we get the benefit
+    // of all the relevant highlighting queries.
+    let cn = config.highlight_query.capture_names();
+    for (idx, name) in cn.iter().enumerate() {
+        if name == "type"
+            || name.starts_with("type.")
+            || name.starts_with("storage.type.")
+            || name.starts_with("keyword.type.")
+            || name == "tag"
+        {
+            // TODO: this doesn't capture (type_ref) in Elm as that
+            // applies to the parent node.
+            type_capture_ids.push(idx as u32);
+        } else if name == "keyword"
+            || name.starts_with("keyword.")
+            || name == "constant"
+            || name.starts_with("constant.")
+            || name == "operator"
+            || name == "repeat"
+            || name == "boolean"
+        {
+            keyword_ish_capture_ids.push(idx as u32);
+        }
+
+        if name == "string"
+            || name.starts_with("string.")
+            || name == "character"
+            || name.starts_with("character.")
+        {
+            string_capture_ids.push(idx as u32);
+        }
+
         // Rust uses 'label' for lifetimes, and highglighting
         // lifetimes consistently with types seems reasonable.
-        type_capture_ids.push(idx);
-    }
-    if let Some(idx) = config.highlight_query.capture_index_for_name("tag") {
-        type_capture_ids.push(idx);
+        if name == "label" {
+            type_capture_ids.push(idx as u32);
+        }
     }
 
     let mut qc = ts::QueryCursor::new();
@@ -843,7 +878,7 @@ fn syntax_from_cursor<'a>(
         let position = nl_pos.from_offsets(node.start_byte(), node.end_byte());
         let content = &src[node.start_byte()..node.end_byte()];
 
-        warn!(
+        debug!(
             "Tree-sitter syntax error at {:?}: {}",
             position.get(0),
             content
